Virtual Keyboard Basic Scientific Calculator Demo

# Virtual Keyboard Scientific Calculator

#### This is a very basic demo of a scientific calculator.*

* I am not a math expert, nor was I trying to make a comprehensive scientific calculator. This demo was simply made to show the versitility of this plugin. If you would like to correct and/or update this demo, please feel free to fork this repository then send me a pull request, or submit an issue. I don't plan on doing much more with this demo otherwise.